@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponse.h 2087 2006-11-25 20:14:11Z svn $
+ * $Id: ApacheResponse.h 2168 2006-12-03 20:56:04Z svn $
  *****************************************************************************/
 
 #ifndef APACHE_RESPONSE_H
@@ -156,6 +156,10 @@ public:
     {
         apr_table_set(r->headers_out, "Content-Disposition", dispos);
     };
+    static void set_env(Handle *r, const char *name, const char *value)
+    {
+        apr_table_setn(r->subprocess_env, name, value);
+    };
 };
 
 #endif
