@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: FileWriter.h 2035 2006-11-23 16:14:21Z svn $
+ * $Id: FileWriter.h 2165 2006-12-03 19:06:50Z svn $
  *****************************************************************************/
 
 #ifndef FILE_WRITER_H
@@ -70,6 +70,18 @@ public:
         write_impl(buffer, size);
         write_size_ += size;
     }
+    /**
+     * ファイルへの書き出しを行います．
+     * 実際の書き込み処理は write_impl に委譲します．
+     *
+     * @param[in] buffer 書き出すデータ
+     * @param[in,out] size 書き出すサイズ
+     * @exception const char * 書き出しに失敗した場合
+     */
+    void write(const void *buffer, apr_size_t *size)
+    {
+        write(buffer, *size);
+    };
     /**
      * ファイルを閉じます．
      *
@@ -86,6 +98,7 @@ public:
      * ファイルを閉じます．
      */
     virtual ~FileWriter();
+
 protected:
     /**
      * ファイルへの書き出しを実際に行います．
