@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 2148 2006-12-01 18:06:29Z svn $
+ * $Id: UploadItem.h 2173 2006-12-06 16:12:56Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_H
@@ -98,7 +98,7 @@ public:
     {
         return header_.index;
     }
-    apr_size_t get_download_count() const
+    apr_size_t get_download_count()
     {
         return  apr_atomic_read(&(header_.download_count));
     }
