@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 2169 2006-12-04 16:26:56Z svn $
+ * $Id: UploadItemList.h 2173 2006-12-06 16:12:56Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_HEADER_LIST_H
@@ -45,7 +45,8 @@ using namespace std;
 class UploadItemList: public Uncopyable
 {
 public:
-    UploadItemList(apr_shm_t *shm, apr_size_t max_list_size);
+    UploadItemList(apr_shm_t *shm, apr_uint64_t max_file_size,
+                   apr_size_t max_list_size);
     /**
      * アイテムをリストに追加します．
      *
@@ -86,18 +87,22 @@ public:
     {
         return *total_file_size_;
     };
-    bool is_full() const
+    bool is_full(apr_off_t file_size) const
     {
-        return (size() == max_list_size_);
+        return (static_cast<apr_uint64_t>(*total_file_size_ + file_size) >
+                max_file_size_) ||
+            (size() == max_list_size_);
     };
     /**
      * プールを使ってインスタンスを生成します．
      *
      * @param[in] shm 共有メモリ
+     * @param[in] max_file_size リストの最大合計ファイルサイズ
      * @param[in] max_list_size リストの最大サイズ
      * @return UploadItemList のインスタンス
      */
     static UploadItemList *get_instance(apr_shm_t *shm,
+                                        apr_uint64_t max_file_size,
                                         apr_size_t max_list_size);
     /**
      * 共有メモリを使って子プロセス用の初期化を行います．
@@ -142,6 +147,7 @@ private:
     UploadItem::header_t *header_list_;
     apr_size_t *header_list_size_;
     apr_off_t *total_file_size_;
+    apr_uint64_t max_file_size_;
     apr_size_t max_list_size_;
 };
 
