@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.h 2168 2006-12-03 20:56:04Z svn $
+ * $Id: UploaderConfig.h 2179 2006-12-07 12:47:20Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_CONFIG_H
@@ -63,6 +63,7 @@ public:
         DOWNLOAD_VIEW,
         THUMBNAIL_VIEW,
         ADMIN_VIEW,
+        ERROR_VIEW,
     };
 
     static const item_t BASE_URL;
@@ -81,6 +82,7 @@ public:
     static const item_t DOWNLOAD_VIEW_TEMPLATE;
     static const item_t THUMBNAIL_VIEW_TEMPLATE;
     static const item_t ADMIN_VIEW_TEMPLATE;
+    static const item_t ERROR_VIEW_TEMPLATE;
 
     UploaderConfig(apr_pool_t *pool);
 
@@ -154,7 +156,7 @@ private:
     UploadItemManager *item_manager_;
     PostFlowController *flow_controller_;
 
-    UploaderTemplate *tmpls_[5];
+    UploaderTemplate *tmpls_[6];
 };
 
 #endif
