@@ -22,11 +22,19 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CharCodeConverter.cpp 2086 2006-11-25 19:48:59Z svn $
+ * $Id: CharCodeConverter.cpp 2179 2006-12-07 12:47:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
 
+#ifndef WIN32
+#ifdef HAVE_ICONV_H
+#ifndef APU_HAVE_ICONV
+#define APU_HAVE_ICONV 1
+#endif
+#endif
+#endif
+
 #if APU_HAVE_ICONV
 #include <iconv.h>
 #elif APU_HAVE_APR_ICONV
@@ -60,6 +68,7 @@ const char *CharCodeConverter::convert(apr_pool_t *pool, const char *str,
     }
 
 #if APU_HAVE_ICONV
+    char *buffer;
     ICONV_2ND_ARG_TYPE target;
     size_t str_len = strlen(str);
     size_t buffer_len = str_len * 3;
@@ -70,8 +79,8 @@ const char *CharCodeConverter::convert(apr_pool_t *pool, const char *str,
     buffer_len--;
 
     if ((handle = iconv_open(to, from)) == reinterpret_cast<iconv_t>(-1)) {
-        THROW(apr_pstrcat(pool, MESSAGE_ICONV_CONVERTER_NOT_FOUND,
-                          "(", from, " -> ", to, ")", NULL));
+        throw apr_pstrcat(pool, MESSAGE_ICONV_CONVERTER_NOT_FOUND,
+                          "(", from, " -> ", to, ")", NULL);
     }
     iconv(handle, &target, &str_len, &buffer, &buffer_len);
     iconv_close(handle);
@@ -86,13 +95,14 @@ const char *CharCodeConverter::convert(apr_pool_t *pool, const char *str,
     buffer_len--;
 
     if (apr_iconv_open(to, from, pool, &handle) != APR_SUCCESS) {
-        THROW(apr_pstrcat(pool, MESSAGE_ICONV_CONVERTER_NOT_FOUND,
-                          "(", from, " -> ", to, ")", NULL));
+        throw apr_pstrcat(pool, MESSAGE_ICONV_CONVERTER_NOT_FOUND,
+                          "(", from, " -> ", to, ")", NULL);
     }
     apr_iconv(handle,
               &str, &str_len, &buffer, &buffer_len, &converted_len);
     apr_iconv_close(handle, pool);
 #else
+
     // iconv，apr_iconv が無い場合，文字コード変換は行わない
     converted = apr_pstrdup(pool, str);
 #endif
