@@ -22,10 +22,12 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.cpp 2047 2006-11-23 18:57:33Z svn $
+ * $Id: MmapFileWriter.cpp 2162 2006-12-03 14:36:10Z svn $
  *****************************************************************************/
 
+#ifndef TEMPLATE_INSTANTIATION
 #include "Environment.h"
+#endif
 
 #if defined(HAVE_UNISTD_H) && !defined(WIN32)
 #include <unistd.h>
@@ -36,9 +38,10 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: MmapFileWriter.cpp 2047 2006-11-23 18:57:33Z svn $");
+#ifndef TEMPLATE_INSTANTIATION
+SOURCE_INFO_ADD("$Id: MmapFileWriter.cpp 2162 2006-12-03 14:36:10Z svn $");
+#endif
 
-const apr_int32_t MmapFileWriter::OPEN_FLAG     = APR_READ|APR_WRITE|APR_BINARY;
 #if defined(HAVE_GETPAGESIZE) && !defined(WIN32)
 const apr_size_t MmapFileWriter::PAGE_SIZE      = getpagesize();
 #else
