@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.cpp 2147 2006-12-01 17:59:57Z svn $
+ * $Id: PostDataChecker.cpp 2163 2006-12-03 15:12:04Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2147 2006-12-01 17:59:57Z svn $");
+SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2163 2006-12-03 15:12:04Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -51,9 +51,6 @@ void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_off_t file_size,
     const char *file_ext;
     apr_size_t escaped_length;
 
-    cout << "PostDataChecker::validate_uitem" << endl;
-    cerr << "PostDataChecker::validate_uitem" << endl;
-
     validate_file_name(file_name);
 
     file_ext = get_file_ext(file_name);
@@ -63,6 +60,9 @@ void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_off_t file_size,
     } else if (strlen(file_name) > (ITM_MAX_FILE_NAME_SIZE-1)) {
         THROW(MESSAGE_POST_FILE_NAME_TOO_LONG);
     }
+    if (file_size == 0) {
+        THROW(MESSAGE_POST_FILE_SIZE_ZERO);
+    }
     if (strlen(file_mime) == 0) {
         THROW(MESSAGE_POST_FILE_MIME_EMPTY);
     } else if (strlen(file_mime) > (ITM_MAX_FILE_MIME_SIZE-1)) {
