@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC2822Parser.cpp 2162 2006-12-03 14:36:10Z svn $
+ * $Id: RFC2822Parser.cpp 2175 2006-12-06 17:27:48Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -39,7 +39,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: RFC2822Parser.cpp 2162 2006-12-03 14:36:10Z svn $");
+SOURCE_INFO_ADD("$Id: RFC2822Parser.cpp 2175 2006-12-06 17:27:48Z svn $");
 #endif
 
 #define AS_CONTENT(pointer)         reinterpret_cast<content_t *>(pointer)
@@ -265,29 +265,6 @@ void RFC2822Parser<R, W>::parse_header()
     skip_header();
 }
 
-// template<class R, class W>
-// const char *RFC2822Parser<R, W>::get_boundary(const char *content_type)
-// {
-//     const char *boundary;
-//     const char *start;
-//     const char *end;
-
-//     TRACE_FUNC;
-
-//     start = M::skip(content_type, MULTIPART_FORM_DATA);
-//     end = content_type+strlen(content_type);
-
-
-//     if (strlen(boundary) <= strlen(M::BOUNDARY_PREFIX)) {
-//         THROW(MESSAGE_RFC2822_CONTENT_TYPE_INVALID);
-//     } else if (strlen(boundary) > (M::READ_BLOCK_SIZE/2)) {
-//         THROW(MESSAGE_RFC2822_CONTENT_TYPE_INVALID);
-//     }
-
-//     return boundary;
-// }
-
-
 
 /******************************************************************************
  * テスト
@@ -299,7 +276,9 @@ void RFC2822Parser<R, W>::parse_header()
 #include "CGIRequestReader.h"
 #include "BasicFileWriter.h"
 
+#define TEMPLATE_INSTANTIATION
 #include "MultipartMessageParser.cpp"
+#include "Base64FileWriter.cpp"
 
 #include <fstream>
 
@@ -309,7 +288,8 @@ static const apr_size_t MAX_FILE_SIZE   = 100 * 1024 * 1024;
 static const apr_size_t MAX_ITEM_NUM    = 10;
 
 typedef RFC2822Parser<CGIRequestReader> RFC2822ParserImpl;
-typedef MultipartMessageParser<CGIRequestReader> MessageParserImpl;
+typedef MultipartMessageParser<CGIRequestReader,
+                               Base64FileWriter<BasicFileWriter> > MessageParserImpl;
 
 void show_usage(const char *prog_name)
 {
