@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 2169 2006-12-04 16:26:56Z svn $
+ * $Id: UploadItemList.cpp 2173 2006-12-06 16:12:56Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,7 +38,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2169 2006-12-04 16:26:56Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2173 2006-12-06 16:12:56Z svn $");
 
 #define AS_UHEADER(pointer)     reinterpret_cast<UploadItem::header_t *>(pointer)
 #define AS_UITEM_LIST(pointer)  reinterpret_cast<UploadItemList *>(pointer)
@@ -46,8 +46,10 @@ SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2169 2006-12-04 16:26:56Z svn $");
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
-UploadItemList::UploadItemList(apr_shm_t *shm, apr_size_t max_list_size)
+UploadItemList::UploadItemList(apr_shm_t *shm, apr_uint64_t max_file_size,
+                               apr_size_t max_list_size)
   : header_list_(0),
+    max_file_size_(max_file_size),
     max_list_size_(max_list_size)
 {
 #ifdef DEBUG
@@ -107,12 +109,13 @@ void UploadItemList::remove(apr_size_t item_id)
 }
 
 UploadItemList *UploadItemList::get_instance(apr_shm_t *shm,
+                                             apr_uint64_t max_file_size,
                                              apr_size_t max_list_size)
 {
     UploadItemList *uheader_list;
 
     uheader_list = AS_UITEM_LIST(apr_shm_baseaddr_get(shm));
-    new(uheader_list) UploadItemList(shm, max_list_size);
+    new(uheader_list) UploadItemList(shm, max_file_size, max_list_size);
 
     return uheader_list;
 }
