@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2168 2006-12-03 20:56:04Z svn $
+ * $Id: UploaderConfig.cpp 2179 2006-12-07 12:47:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2168 2006-12-03 20:56:04Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2179 2006-12-07 12:47:20Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
@@ -85,25 +85,29 @@ const UploaderConfig::item_t UploaderConfig::PER_PAGE_ITEM_NUMBER = {
     "Per Page Item Number",
 };
 const UploaderConfig::item_t UploaderConfig::INDEX_VIEW_TEMPLATE = {
-    PARAM_PREFIX "IndexVIewTemplate",
+    PARAM_PREFIX "IndexViewTemplate",
     "Template of index view",
 };
 const UploaderConfig::item_t UploaderConfig::PROGRESS_VIEW_TEMPLATE = {
-    PARAM_PREFIX "ProgressVIewTemplate",
+    PARAM_PREFIX "ProgressViewTemplate",
     "Template of progress view",
 };
 const UploaderConfig::item_t UploaderConfig::DOWNLOAD_VIEW_TEMPLATE = {
-    PARAM_PREFIX "DownloadVIewTemplate",
+    PARAM_PREFIX "DownloadViewTemplate",
     "Template of download view",
 };
 const UploaderConfig::item_t UploaderConfig::THUMBNAIL_VIEW_TEMPLATE = {
-    PARAM_PREFIX "ThumbnailVIewTemplate",
+    PARAM_PREFIX "ThumbnailViewTemplate",
     "Template of thumbnail view",
 };
 const UploaderConfig::item_t UploaderConfig::ADMIN_VIEW_TEMPLATE = {
-    PARAM_PREFIX "AdminVIewTemplate",
+    PARAM_PREFIX "AdminViewTemplate",
     "Template of admin view",
 };
+const UploaderConfig::item_t UploaderConfig::ERROR_VIEW_TEMPLATE = {
+    PARAM_PREFIX "ErrorViewTemplate",
+    "Template of error view",
+};
 
 
 /******************************************************************************
@@ -158,6 +162,7 @@ void UploaderConfig::init()
     item_list_ = UploadItemListReader::read(pool_, data_dir_path,
                                             thumb_dir_path, item_list_shm_,
                                             thumbnail_list_,
+                                            total_file_size_limit,
                                             total_file_number_limit);
     item_manager_ = UploadItemManager::get_instance(item_manager_shm_, pool_,
                                                     data_dir_path,
