@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2170 2006-12-04 17:23:49Z svn $
+ * $Id: uploader_handler.cpp 2179 2006-12-07 12:47:20Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -55,7 +55,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2170 2006-12-04 17:23:49Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2179 2006-12-07 12:47:20Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -67,12 +67,13 @@ static const char BASE_URL_VAR_NAME[]           = "BASE_URL";
 static const char ITEM_VAR_NAME[]               = "ITEM";
 static const char ITEM_LIST_VAR_NAME[]          = "ITEM_LIST";
 static const char THUMBNAIL_LIST_VAR_NAME[]     = "THUMBNAIL_LIST";
-static const char MAX_FILE_SIZE[]               = "MAX_FILE_SIZE";
-static const char TOTAL_FILE_SIZE[]             = "TOTAL_FILE_SIZE";
-static const char TOTAL_FILE_NUMBER[]           = "TOTAL_FILE_NUMBER";
-static const char TOTAL_THUMBNAIL_NUMBER[]      = "TOTAL_THUMBNAIL_NUMBER";
-static const char PAGE_COUNT[]                  = "PAGE_COUNT";
-static const char CURRENT_PAGE[]                = "CURRENT_PAGE";
+static const char MAX_FILE_SIZE_VAR_NAME[]      = "MAX_FILE_SIZE";
+static const char TOTAL_FILE_SIZE_VAR_NAME[]    = "TOTAL_FILE_SIZE";
+static const char TOTAL_FILE_NUMBER_VAR_NAME[]  = "TOTAL_FILE_NUMBER";
+static const char TOTAL_THUMBNAIL_NUMBER_VAR_NAME[] = "TOTAL_THUMBNAIL_NUMBER";
+static const char PAGE_COUNT_VAR_NAME[]         = "PAGE_COUNT";
+static const char CURRENT_PAGE_VAR_NAME[]       = "CURRENT_PAGE";
+static const char ERROR_MESSAGE_VAR_NAME[]      = "ERROR_MESSAGE";
 
 static const char INDEX_COMMAND[]               = "index";
 static const char THUMBNAIL_COMMAND[]           = "thumbnail";
@@ -118,6 +119,19 @@ static int redirect(typename Response::Handle *r, typename Response::Writer& o,
     return OK;
 }
 
+template<class Response>
+static int error_without_template(typename Response::Handle *r,
+                                  typename Response::Writer& o,
+                                  UploaderConfig *config, const char *message)
+{
+    o.write("<div class=\"warning\">ERROR: ");
+    o.write(message);
+    o.write("</div>\n");
+    o.finish();
+
+    return OK;
+}
+
 template<class Response>
 static int error(typename Response::Handle *r,
                  typename Response::Writer& o,
@@ -125,9 +139,23 @@ static int error(typename Response::Handle *r,
 {
     Response::set_content_type(r, "text/html");
 
-    o.write("<div class=\"warning\">ERROR: ");
-    o.write(message);
-    o.write("</div>\n");
+    try {
+        UploaderTemplate *tmpl;
+
+        tmpl = config->get_template(UploaderConfig::ERROR_VIEW);
+
+        TemplateVariableCreator var_creator(r->pool, tmpl->get_ids());
+
+        var_creator.create(BASE_URL_VAR_NAME, config->base_url);
+        var_creator.create(ERROR_MESSAGE_VAR_NAME, message);
+
+        TemplateExecutor<typename Response::Writer> executor(r->pool, o);
+
+        executor.exec(tmpl->get_node_tree(), var_creator.get_variables(),
+                      tmpl->get_key_count());
+    } catch(const char *message) {
+        return error_without_template<Response>(r, o, config, message);
+    }
     o.finish();
 
     return OK;
@@ -212,16 +240,16 @@ static int index(typename Response::Handle *r, UploaderConfig *config,
             (ITEM_LIST_VAR_NAME,
              tmpl->get_item_var_creator()->create(r->pool, &item_iter));
 
-        var_creator.create(MAX_FILE_SIZE,
+        var_creator.create(MAX_FILE_SIZE_VAR_NAME,
                            size_str(r->pool, config->file_size_limit));
         var_creator.create
-            (TOTAL_FILE_SIZE,
+            (TOTAL_FILE_SIZE_VAR_NAME,
              size_str(r->pool,
                       config->get_item_list()->get_total_file_size()));
-        var_creator.create(TOTAL_FILE_NUMBER, config->get_item_list()->size());
-        var_creator.create(PAGE_COUNT, page_count);
+        var_creator.create(TOTAL_FILE_NUMBER_VAR_NAME, config->get_item_list()->size());
+        var_creator.create(PAGE_COUNT_VAR_NAME, page_count);
 
-        var_creator.create(CURRENT_PAGE, page_no);
+        var_creator.create(CURRENT_PAGE_VAR_NAME, page_no);
 
         TemplateExecutor<typename Response::Writer> executor(r->pool, o);
 
@@ -337,11 +365,11 @@ static int thumbnail(typename Response::Handle *r, UploaderConfig *config,
              tmpl->get_thumbnail_var_creator()->create(r->pool,
                                                        &thumbnail_iter));
 
-        var_creator.create(TOTAL_THUMBNAIL_NUMBER,
+        var_creator.create(TOTAL_THUMBNAIL_NUMBER_VAR_NAME,
                            config->get_thumbnail_list()->size());
-        var_creator.create(PAGE_COUNT, page_count);
+        var_creator.create(PAGE_COUNT_VAR_NAME, page_count);
 
-        var_creator.create(CURRENT_PAGE, page_no);
+        var_creator.create(CURRENT_PAGE_VAR_NAME, page_no);
 
         TemplateExecutor<typename Response::Writer> executor(r->pool, o);
 
@@ -792,16 +820,16 @@ static int admin(typename Response::Handle *r, UploaderConfig *config,
             (ITEM_LIST_VAR_NAME,
              tmpl->get_item_var_creator()->create(r->pool, &item_iter));
 
-        var_creator.create(MAX_FILE_SIZE,
+        var_creator.create(MAX_FILE_SIZE_VAR_NAME,
                            size_str(r->pool, config->file_size_limit));
         var_creator.create
-            (TOTAL_FILE_SIZE,
+            (TOTAL_FILE_SIZE_VAR_NAME,
              size_str(r->pool,
                       config->get_item_list()->get_total_file_size()));
-        var_creator.create(TOTAL_FILE_NUMBER, config->get_item_list()->size());
-        var_creator.create(PAGE_COUNT, page_count);
+        var_creator.create(TOTAL_FILE_NUMBER_VAR_NAME, config->get_item_list()->size());
+        var_creator.create(PAGE_COUNT_VAR_NAME, page_count);
 
-        var_creator.create(CURRENT_PAGE, page_no);
+        var_creator.create(CURRENT_PAGE_VAR_NAME, page_no);
 
         TemplateExecutor<typename Response::Writer> executor(r->pool, o);
 
